###################################################
### chunk number 1: models
###################################################
pt <- read.csv("pt.csv")
library(apsrtable)
model1 <- lm(cgexp ~ 
             pres + maj +  
             lyp + gastil + age + trade + 
             prop65 + prop1564 + federal +
             oecd, data=pt)
model2 <- lm(cgexp ~ 
             pres + maj +
             lyp + gastil + age + trade + 
             prop65 + prop1564 + federal +
             oecd + col_uka + col_espa + col_otha +
             africa + asiae + laam, data=pt)
model3 <- lm(cgexp ~ 
             pro.pres + maj.parl + maj.pres + 
             lyp + gastil + age + trade + 
             prop65 + prop1564 + federal +
             oecd + col_uka + col_espa + col_otha +
             africa + asiae + laam, data=pt)


###################################################
### chunk number 2: robust
###################################################
## Add robust se to the models
library(sandwich)
model1$se <- vcovHC(model1,type="HC1")
model2$se <- vcovHC(model2,type="HC1")
model3$se <- vcovHC(model3,type="HC1")


## Create and register custom modelInfo for lm

setMethod("modelInfo", "summary.lm", function(x) {
  env <- parent.frame()
  digits <- evalq(digits,env)
  model.info <- list(
    "Continents"= (
        ifelse(!is.na(charmatch("laam",rownames(coef(x)))),
          "\\multicolumn{1}{c}{Yes}", "\\multicolumn{1}{c}{No}")),
    "Colonies" = (
        ifelse(!is.na(charmatch("col",rownames(coef(x)))),
          "\\multicolumn{1}{c}{Yes}", "\\multicolumn{1}{c}{No}")),
    "Number of\\tabularnewline Observations"= (
        formatC(sum(x$df[1:2]),format="d")),
    "adj. $R^2$" = (
        formatC(x$adj.r.squared,format="f",digits=digits)))
class(model.info) <- "model.info"
return(model.info)
} )


###################################################
### chunk number 3: finaltable eval=FALSE
###################################################
## apsrtable(model1,model2,model3,
## omitcoef=list(expression(grep("col_",coefnames,value=TRUE)),
##   "(Intercept)","lyp", "gastil", "age", "trade", 
##   "prop65", "prop1564", "federal" ,
##   "oecd" , "africa", "asiae", "laam"),
## coef.names=c("Presidential","Majoritatian",
##   "Proportional Presidential",
##   "Majoritarian Parliamentary",
##   "Majoritarian Presidential"),
## align="left",stars="default",
## notes=list(se.note(), stars.note())
## )


###################################################
### chunk number 4: printfinaltable
###################################################
apsrtable(model1,model2,model3,
omitcoef=list(expression(grep("col_",coefnames,value=TRUE)),
  "(Intercept)","lyp", "gastil", "age", "trade", 
  "prop65", "prop1564", "federal" ,
  "oecd" , "africa", "asiae", "laam"),
coef.names=c("Presidential","Majoritatian",
  "Proportional Presidential",
  "Majoritarian Parliamentary",
  "Majoritarian Presidential"),
align="left",stars="default",
notes=list(se.note(), stars.note())
,Sweave=TRUE) 


